/*
   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once

#include <PimCommon/TemplateListWidget>

namespace ThemeDefaultTemplate
{
Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
}

